
GooseSLURM
==========

.. |badge1| image:: https://img.shields.io/badge/license-MIT-brightgreen.svg
  :target: https://github.com/tdegeus/GooseSLURM/blob/master/LICENSE
  :alt: MIT license

.. |badge2| image:: https://img.shields.io/badge/warranty-no-red.svg
  :target: https://github.com/tdegeus/GooseSLURM/blob/master/LICENSE
  :alt: MIT license

.. |badge3| image:: https://img.shields.io/badge/download-.zip-lightgray.svg
  :target: https://github.com/tdegeus/GooseSLURM/zipball/master
  :alt: Download as .zip

.. |badge4| image:: https://img.shields.io/badge/download-.tar.gz-lightgray.svg
  :target: https://github.com/tdegeus/GooseSLURM/tarball/master
  :alt: Download as .tar.gz

.. |badge5| image:: https://img.shields.io/badge/contact-tom@geus.me-blue.svg
  :target: mailto:tom@geus.me
  :alt: Contact tom@geus.me

.. |badge6| image:: https://img.shields.io/badge/contact-www.geus.me-blue.svg
  :target: http://www.geus.me
  :alt: Website www.geus.me

.. |badge7| image:: https://img.shields.io/badge/GitHub-tdegeus/GooseSLURM-blue.svg
  :target: https://github.com/tdegeus/GooseSLURM
  :alt: Github tdegeus/GooseSLURM

.. |badge8| image:: https://img.shields.io/badge/documentation-GooseSLURM.geus.me-blue.svg
  :target: http://GooseSLURM.geus.me
  :alt: Website GooseSLURM.geus.me

| |badge1| |badge2| |badge3| |badge4|
| |badge5| |badge6| |badge7|
| |badge8|

.. note::

  This library is free to use under the `MIT license <https://github.com/tdegeus/GooseSLURM/blob/master/LICENSE>`_. Any additions are very much appreciated, in terms of suggested functionality, code, documentation, testimonials, word of mouth advertisement, .... Bugs or feature requests can be filed on `GitHub <http://github.com/tdegeus/GooseSLURM>`_. As always, the code comes with no guarantee. None of the developers can be held responsible for possible mistakes.

.. toctree::
   :caption: BASICS
   :maxdepth: 1

   cluster.rst
   linux.rst
   cheat-sheet.rst

.. toctree::
   :caption: TOOLS
   :maxdepth: 1

   getting.rst
   scripts.rst
   python.rst

.. toctree::
   :caption: TIPS & EXAMPLES
   :maxdepth: 1

   buffer.rst
   copy.rst
   conda.rst
   examples/parallel/readme.rst
   examples/tempdir/readme.rst
   examples/json_log/readme.rst

.. toctree::
   :caption: DEVELOP
   :maxdepth: 1

   changelog.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
